@@ -1,6 +1,6 @@
 package Test::Mocha;
 # ABSTRACT: Test double framework with method stubs and behaviour verification
-$Test::Mocha::VERSION = '0.63';
+$Test::Mocha::VERSION = '0.64';
 
 use strict;
 use warnings;
@@ -264,7 +264,7 @@ Test::Mocha - Test double framework with method stubs and behaviour verification
 
 =head1 VERSION
 
-version 0.63
+version 0.64
 
 =head1 SYNOPSIS
 
@@ -697,7 +697,15 @@ for Java and Python by Szczepan Faber.
 It is not associated with the Javascript test framework for node.js called
 Mocha. I named Test::Mocha before that came about.
 
-The C<class_mock()> function was contributed by Scott Davis.
+Thanks to the following people who have contributed to Test::Mocha:
+
+=over
+
+Scott Davis for adding the C<class_mock()> function.
+
+Chad Granum <exodist@cpan.org>
+
+=back
 
 =head1 SEE ALSO
 
